%define url_ver %(echo %{version}|cut -d. -f1,2)


%define api	0.18
%define major	0
%define libname	%mklibname %{name} %{api} %major
%define	devname	%mklibname -d %{name}

#gw checks don't run in iurt
%define	with_check 0

Summary:	Compiler for the GObject type system
Name:		vala
Version:	0.18.0
Release:	1
# Most files are LGPLv2.1+, curses.vapi is 2-clause BSD
License:	LGPLv2+ and BSD
Group:		Development/Other
Url:		http://live.gnome.org/Vala
Source0:	ftp://ftp.gnome.org/pub/GNOME/sources/vala/%{url_ver}/%{name}-%{version}.tar.xz

BuildRequires:	bison
BuildRequires:	flex
BuildRequires:	xsltproc
BuildRequires:	pkgconfig(glib-2.0) >= 2.25
%if %{with_check}
BuildRequires:	pkgconfig(dbus-glib-1)
%endif

%description
Vala is a new programming language that aims to bring modern
programming language features to GNOME developers without imposing any
additional runtime requirements and without using a different ABI
compared to applications and libraries written in C.

valac, the Vala compiler, is a self-hosting compiler that translates
Vala source code into C source and header files. It uses the GObject
type system to create classes and interfaces declared in the Vala
source code. It's also planned to generate GIDL files when
gobject-introspection is ready.

The syntax of Vala is similar to C#, modified to better fit the GObject
type system. Vala supports modern language features as the following:

* Interfaces
* Properties
* Signals
* Foreach
* Lambda expressions
* Type inference for local variables
* Non-null types [PARTIAL]
* Exception handling [PLANNED]
* Assisted memory management

* type modules (aka. Plugins) 

Vala is designed to allow access to existing C libraries, especially
GObject-based libraries, without the need for runtime bindings. Each
to be used library requires a Vala API file at compile-time,
containing the class and method declarations in Vala syntax. Vala
currently comes with experimental bindings for GLib and GTK+. It's
planned to provide generated bindings for the full GNOME Platform at a
later stage.

Using classes and methods written in Vala from an application written
in C is not difficult. The Vala library only has to install the
generated header files and C applications may then access the
GObject-based API of the Vala library as usual. It should also be
easily possible to write a bindings generator for access to Vala
libraries from applications written in e.g. C# as the Vala parser is written 
as a library, so that all compile-time information is available when
generating a binding.

%package -n %{libname}
Group:		System/Libraries
Summary:	Vala runtime library

%description -n %{libname}
This is the runtime library of the Vala programming language.

%package -n %{devname}
Group:		Development/Other
Summary:	Vala development files
Requires:	%{libname} = %{version}-%{release}
Provides:	vala-devel = %{version}-%{release}
Obsoletes:	%mklibname -d vala 0

%description -n %{devname}
This is the development library of the Vala programming language.

%package tools
Summary:	Tools for creating projects and bindings for %{name}
Group:		Development/Other
Requires:	%{name} = %{version}-%{release}
Requires:	gnome-common
Requires:	intltool
Requires:	libtool

%description tools
This package contains tools to generate Vala projects, as well as API bindings
from existing C libraries, allowing access from Vala programs.

%prep
%setup -q
%apply_patches

%build
%configure2_5x \
	--enable-vapigen

%make

%install
%makeinstall_std
find %{buildroot} -name "*.la" -delete

mkdir -p %{buildroot}%{_datadir}/vala/vapi

%if %{with_check}
%check
%make check
%endif

%files
%doc NEWS README
%{_bindir}/vala
%{_bindir}/vala-%{api}
%{_bindir}/valac
%{_bindir}/valac-%{api}
%{_datadir}/vala-%{api}
%dir %{_datadir}/vala
%dir %{_datadir}/vala/vapi
%{_mandir}/man1/valac.1*
%{_mandir}/man1/valac-%{api}.1*

%files -n %{libname}
%{_libdir}/libvala-%{api}.so.%{major}*

%files -n %{devname}
%doc ChangeLog AUTHORS MAINTAINERS
%{_includedir}/vala-%{api}
%{_libdir}/libvala-%{api}.so
%{_libdir}/pkgconfig/*.pc
%{_datadir}/pkgconfig/*.pc
%{_datadir}/devhelp/books/vala-%{api}
%{_datadir}/aclocal/*.m4

%files tools
%{_bindir}/*gen*
%{_bindir}/vapicheck
%{_bindir}/vapicheck-%{api}
%{_datadir}/vala/Makefile.vapigen
%{_libdir}/vala-%{api}
%{_mandir}/*/*gen*



%changelog
* Wed Sep 26 2012 Alexander Khrukin <akhrukin@mandriva.org> 0.18.0-1
+ Revision: 817634
- version update 0.18.0
- url_ver macro
- version update 0.17.7

* Tue Sep 04 2012 Götz Waschk <waschk@mandriva.org> 0.17.6-1
+ Revision: 816309
- update to new version 0.17.6

* Mon Aug 20 2012 Matthew Dawkins <mattydaw@mandriva.org> 0.17.5-1
+ Revision: 815471
- update to new version 0.17.5

* Mon Aug 06 2012 Matthew Dawkins <mattydaw@mandriva.org> 0.17.4-1
+ Revision: 811876
- update to new version 0.17.4

* Mon Jun 25 2012 Matthew Dawkins <mattydaw@mandriva.org> 0.17.2-1
+ Revision: 806847
- new unstable version 0.17.2
- cleanrd up spec

* Sat May 19 2012 Crispin Boylan <crisb@mandriva.org> 0.17.0-1
+ Revision: 799645
- New release

* Tue Apr 24 2012 Matthew Dawkins <mattydaw@mandriva.org> 0.16.0-1
+ Revision: 793194
- new version 0.16.0
- fixed files list

* Tue Jan 31 2012 Götz Waschk <waschk@mandriva.org> 0.14.2-1
+ Revision: 770075
- new version

* Fri Dec 09 2011 Matthew Dawkins <mattydaw@mandriva.org> 0.14.1-2
+ Revision: 739230
- minor detail
- rebuild
- removed .la files
- cleaned up spec
- created with_check

* Thu Dec 01 2011 Götz Waschk <waschk@mandriva.org> 0.14.1-1
+ Revision: 735979
- new version

* Wed Nov 09 2011 Matthew Dawkins <mattydaw@mandriva.org> 0.14.0-1
+ Revision: 729383
- new version 0.14.0
  cleaned up spec

* Mon Jul 11 2011 Eugeni Dodonov <eugeni@mandriva.com> 0.12.1-3
+ Revision: 689580
- Rebuild

* Wed Jun 22 2011 Götz Waschk <waschk@mandriva.org> 0.12.1-2
+ Revision: 686582
- back to stable version 0.12.1

* Sun Jun 19 2011 Jon Dill <dillj@mandriva.org> 0.13.0-1
+ Revision: 685971
- new version to 0.13.0

* Wed Jun 01 2011 Götz Waschk <waschk@mandriva.org> 0.12.1-1
+ Revision: 682354
- new version
- xz tarball

* Fri May 06 2011 Oden Eriksson <oeriksson@mandriva.com> 0.12.0-2
+ Revision: 670760
- mass rebuild

* Mon Apr 04 2011 Funda Wang <fwang@mandriva.org> 0.12.0-1
+ Revision: 650186
- New version 0.12.0

* Sat Mar 12 2011 Götz Waschk <waschk@mandriva.org> 0.10.4-1
+ Revision: 644081
- update to new version 0.10.4

* Sat Jan 22 2011 Götz Waschk <waschk@mandriva.org> 0.10.3-1
+ Revision: 632216
- update to new version 0.10.3

* Wed Dec 29 2010 Götz Waschk <waschk@mandriva.org> 0.10.2-1mdv2011.0
+ Revision: 625978
- update to new version 0.10.2
- own vala/vapi dir

* Tue Oct 26 2010 Götz Waschk <waschk@mandriva.org> 0.10.1-1mdv2011.0
+ Revision: 589528
- update to new version 0.10.1

* Sat Sep 18 2010 Götz Waschk <waschk@mandriva.org> 0.10.0-1mdv2011.0
+ Revision: 579347
- update to new version 0.10.0

* Sat Sep 04 2010 Götz Waschk <waschk@mandriva.org> 0.9.8-1mdv2011.0
+ Revision: 575949
- update to new version 0.9.8

* Thu Aug 19 2010 Götz Waschk <waschk@mandriva.org> 0.9.7-1mdv2011.0
+ Revision: 571314
- update to new version 0.9.7

* Wed Aug 18 2010 Götz Waschk <waschk@mandriva.org> 0.9.6-1mdv2011.0
+ Revision: 571173
- update to new version 0.9.6

* Mon Aug 09 2010 Götz Waschk <waschk@mandriva.org> 0.9.5-1mdv2011.0
+ Revision: 567977
- new version
- update file list

* Thu Jul 29 2010 Götz Waschk <waschk@mandriva.org> 0.9.4-1mdv2011.0
+ Revision: 563082
- new version
- drop patch
- bump glib dep
- add %%_bindir/vala

* Wed Apr 21 2010 Götz Waschk <waschk@mandriva.org> 0.8.1-1mdv2010.1
+ Revision: 537648
- update to new version 0.8.1

* Wed Mar 31 2010 Götz Waschk <waschk@mandriva.org> 0.8.0-1mdv2010.1
+ Revision: 530533
- update to new version 0.8.0

* Thu Feb 04 2010 Götz Waschk <waschk@mandriva.org> 0.7.10-1mdv2010.1
+ Revision: 500996
- update to new version 0.7.10

* Sat Dec 19 2009 Götz Waschk <waschk@mandriva.org> 0.7.9-1mdv2010.1
+ Revision: 480162
- update to new version 0.7.9

* Fri Nov 06 2009 Götz Waschk <waschk@mandriva.org> 0.7.8-1mdv2010.1
+ Revision: 460747
- update to new version 0.7.8

* Sat Oct 03 2009 Colin Guthrie <cguthrie@mandriva.org> 0.7.7-2mdv2010.0
+ Revision: 453252
- Fix format-security issues.
- Enable vapigen and package in vala-tools (as per Fedora)

* Sun Sep 27 2009 Götz Waschk <waschk@mandriva.org> 0.7.7-1mdv2010.0
+ Revision: 450206
- update to new version 0.7.7

* Fri Sep 18 2009 Götz Waschk <waschk@mandriva.org> 0.7.6-1mdv2010.0
+ Revision: 444249
- update to new version 0.7.6

* Sun Aug 02 2009 Götz Waschk <waschk@mandriva.org> 0.7.5-1mdv2010.0
+ Revision: 407607
- update to new version 0.7.5

* Sun Jun 28 2009 Götz Waschk <waschk@mandriva.org> 0.7.4-1mdv2010.0
+ Revision: 390425
- update to new version 0.7.4

* Wed May 27 2009 Götz Waschk <waschk@mandriva.org> 0.7.3-1mdv2010.0
+ Revision: 380096
- update build deps
- update to new version 0.7.3

  + Frederic Crozat <fcrozat@mandriva.com>
    - Add dependency on glib2-devel (Mdv bug #50894)
    - Enable checks

* Mon May 11 2009 Götz Waschk <waschk@mandriva.org> 0.7.2-1mdv2010.0
+ Revision: 374162
- new version

* Tue Apr 14 2009 Götz Waschk <waschk@mandriva.org> 0.6.1-1mdv2009.1
+ Revision: 366976
- update to new version 0.6.1

* Tue Mar 31 2009 Götz Waschk <waschk@mandriva.org> 0.6.0-1mdv2009.1
+ Revision: 362800
- new version

* Sat Feb 21 2009 Götz Waschk <waschk@mandriva.org> 0.5.7-1mdv2009.1
+ Revision: 343552
- update to new version 0.5.7

* Sun Jan 18 2009 Götz Waschk <waschk@mandriva.org> 0.5.6-1mdv2009.1
+ Revision: 330983
- update to new version 0.5.6

* Sat Jan 10 2009 Götz Waschk <waschk@mandriva.org> 0.5.5-1mdv2009.1
+ Revision: 328029
- update to new version 0.5.5

* Thu Jan 08 2009 Götz Waschk <waschk@mandriva.org> 0.5.4-1mdv2009.1
+ Revision: 327027
- new version
- drop patch

* Fri Dec 19 2008 Götz Waschk <waschk@mandriva.org> 0.5.3-1mdv2009.1
+ Revision: 316084
- new version
- fix format strings

* Tue Dec 02 2008 Götz Waschk <waschk@mandriva.org> 0.5.2-1mdv2009.1
+ Revision: 309149
- disable checks
- fix checks
- update to new version 0.5.2

* Tue Nov 04 2008 Funda Wang <fwang@mandriva.org> 0.5.1-1mdv2009.1
+ Revision: 299670
- New version 0.5.1

* Tue Oct 21 2008 Götz Waschk <waschk@mandriva.org> 0.4.0-1mdv2009.1
+ Revision: 295930
- new version
- fix source URL

* Thu Aug 14 2008 Götz Waschk <waschk@mandriva.org> 0.3.5-1mdv2009.0
+ Revision: 272193
- new version

* Thu Jul 03 2008 Götz Waschk <waschk@mandriva.org> 0.3.4-1mdv2009.0
+ Revision: 230993
- new version
- update license

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Tue Apr 15 2008 Götz Waschk <waschk@mandriva.org> 0.2.0-1mdv2009.0
+ Revision: 193793
- new version

* Mon Mar 03 2008 Götz Waschk <waschk@mandriva.org> 0.1.7-1mdv2008.1
+ Revision: 177871
- new version

* Sun Jan 20 2008 Götz Waschk <waschk@mandriva.org> 0.1.6-1mdv2008.1
+ Revision: 155296
- new version

  + Olivier Blin <blino@mandriva.org>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Sun Nov 25 2007 Götz Waschk <waschk@mandriva.org> 0.1.5-1mdv2008.1
+ Revision: 111946
- new version

* Tue Oct 09 2007 Götz Waschk <waschk@mandriva.org> 0.1.4-1mdv2008.1
+ Revision: 96572
- new version
- update file list

* Fri Aug 31 2007 Götz Waschk <waschk@mandriva.org> 0.1.3-1mdv2008.0
+ Revision: 76885
- new version

* Sat Jul 28 2007 Götz Waschk <waschk@mandriva.org> 0.1.2-1mdv2008.0
+ Revision: 56459
- new version
- new devel name

* Fri Jul 13 2007 Götz Waschk <waschk@mandriva.org> 0.1.1-1mdv2008.0
+ Revision: 51810
- new version

* Mon Jul 09 2007 Götz Waschk <waschk@mandriva.org> 0.1.0-1mdv2008.0
+ Revision: 50480
- new version

* Mon Apr 30 2007 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 0.0.9-1mdv2008.0
+ Revision: 19638
- Updated to 0.0.9.

